import { Either } from 'fp-ts/lib/Either';
import { PackageJson } from 'type-fest';
declare const malformedPackageJson: (ctx: {
    path: string;
    reason: string;
}) => import("./utils").Exception<"MalformedPackageJson", {
    path: string;
    reason: string;
}>;
export declare type MalformedPackageJsonError = ReturnType<typeof malformedPackageJson>;
export declare type Result = {
    path: string;
    dir: string;
    contents: Either<MalformedPackageJsonError, PackageJson>;
} | null;
/**
 * Find the package.json file path. Looks recursively upward to disk root.
 * Starts looking in CWD If no package.json found along search, returns null.
 * If packge.json fonud but fails to be parsed or fails validation than an error is returned.
 */
export declare function findRecurisvelyUpwardSync(opts: {
    cwd: string;
}): Result;
/**
 * Parse package.json contents.
 */
export declare function parse(contents: string, path: string): import("fp-ts/lib/Either").Left<import("./utils").Exception<"MalformedPackageJson", {
    path: string;
    reason: string;
}>> | import("fp-ts/lib/Either").Right<{
    name?: string | undefined;
    version?: string | undefined;
    description?: string | undefined;
    keywords?: string[] | undefined;
    homepage?: "." | (string & {
        _?: undefined;
    }) | undefined;
    bugs?: string | {
        url?: string | undefined;
        email?: string | undefined;
    } | undefined;
    license?: string | undefined;
    licenses?: {
        type?: string | undefined;
        url?: string | undefined;
    }[] | undefined;
    author?: string | {
        name: string;
        url?: string | undefined;
        email?: string | undefined;
    } | undefined;
    contributors?: PackageJson.Person[] | undefined;
    maintainers?: PackageJson.Person[] | undefined;
    files?: string[] | undefined;
    type?: "module" | "commonjs" | undefined;
    main?: string | undefined;
    exports?: string | {
        node: PackageJson.Exports;
        default: PackageJson.Exports;
        import: PackageJson.Exports;
        require: PackageJson.Exports;
        deno: PackageJson.Exports;
        browser: PackageJson.Exports;
        electron: PackageJson.Exports;
        "react-native": PackageJson.Exports;
    } | {
        [key: string]: PackageJson.Exports;
    } | undefined;
    bin?: string | {
        [binary: string]: string;
    } | undefined;
    man?: string | string[] | undefined;
    directories?: PackageJson.DirectoryLocations | undefined;
    repository?: string | {
        type: string;
        url: string;
        directory?: string | undefined;
    } | undefined;
    scripts?: PackageJson.Scripts | undefined;
    config?: {
        [configKey: string]: unknown;
    } | undefined;
    dependencies?: PackageJson.Dependency | undefined;
    devDependencies?: PackageJson.Dependency | undefined;
    optionalDependencies?: PackageJson.Dependency | undefined;
    peerDependencies?: PackageJson.Dependency | undefined;
    peerDependenciesMeta?: {
        [packageName: string]: {
            optional: true;
        };
    } | undefined;
    bundledDependencies?: string[] | undefined;
    bundleDependencies?: string[] | undefined;
    engines?: {
        [x: string]: string;
    } | undefined;
    engineStrict?: boolean | undefined;
    os?: import("type-fest").LiteralUnion<"aix" | "darwin" | "freebsd" | "linux" | "openbsd" | "sunos" | "win32" | "!aix" | "!darwin" | "!freebsd" | "!linux" | "!openbsd" | "!sunos" | "!win32", string>[] | undefined;
    cpu?: import("type-fest").LiteralUnion<"arm" | "arm64" | "ia32" | "mips" | "mipsel" | "ppc" | "ppc64" | "s390" | "s390x" | "x32" | "x64" | "!arm" | "!arm64" | "!ia32" | "!mips" | "!mipsel" | "!ppc" | "!ppc64" | "!s390" | "!s390x" | "!x32" | "!x64", string>[] | undefined;
    preferGlobal?: boolean | undefined;
    private?: boolean | undefined;
    publishConfig?: {
        [config: string]: unknown;
    } | undefined;
    funding?: string | {
        type?: (string & {
            _?: undefined;
        }) | "github" | "opencollective" | "patreon" | "individual" | "foundation" | "corporation" | undefined;
        url: string;
    } | undefined;
} & PackageJson.NonStandardEntryPoints & PackageJson.TypeScriptConfiguration & PackageJson.YarnConfiguration & PackageJson.JSPMConfiguration & {
    [key: string]: unknown;
} & {
    name: string;
    version: string;
}>;
export {};
//# sourceMappingURL=package-json.d.ts.map